@@ -15,6 +15,14 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+"""
+Hook for Slack.
+
+.. spelling:word-list::
+
+    AsyncSlackResponse
+"""
+
 from __future__ import annotations
 
 import json
@@ -27,21 +35,21 @@ from typing import TYPE_CHECKING, Any, TypedDict
 
 from slack_sdk import WebClient
 from slack_sdk.errors import SlackApiError
+from slack_sdk.web.async_client import AsyncWebClient
 from typing_extensions import NotRequired
 
 from airflow.exceptions import AirflowException, AirflowNotFoundException
-from airflow.providers.slack.utils import ConnectionExtraConfig
-
-try:
-    from airflow.sdk import BaseHook
-except ImportError:
-    from airflow.hooks.base import BaseHook  # type: ignore[attr-defined,no-redef]
+from airflow.providers.slack.utils import ConnectionExtraConfig, get_async_connection
+from airflow.providers.slack.version_compat import BaseHook
 from airflow.utils.helpers import exactly_one
 
 if TYPE_CHECKING:
     from slack_sdk.http_retry import RetryHandler
+    from slack_sdk.web.async_client import AsyncSlackResponse
     from slack_sdk.web.slack_response import SlackResponse
 
+    from airflow.providers.slack.version_compat import Connection
+
 
 class FileUploadTypeDef(TypedDict):
     """
@@ -144,15 +152,20 @@ class SlackHook(BaseHook):
     @cached_property
     def client(self) -> WebClient:
         """Get the underlying slack_sdk.WebClient (cached)."""
-        return WebClient(**self._get_conn_params())
+        conn = self.get_connection(self.slack_conn_id)
+        return WebClient(**self._get_conn_params(conn=conn))
+
+    async def get_async_client(self) -> AsyncWebClient:
+        """Get the underlying `slack_sdk.web.async_client.AsyncWebClient`."""
+        conn = await get_async_connection(self.slack_conn_id)
+        return AsyncWebClient(**self._get_conn_params(conn))
 
     def get_conn(self) -> WebClient:
         """Get the underlying slack_sdk.WebClient (cached)."""
         return self.client
 
-    def _get_conn_params(self) -> dict[str, Any]:
+    def _get_conn_params(self, conn: Connection) -> dict[str, Any]:
         """Fetch connection params as a dict and merge it with hook parameters."""
-        conn = self.get_connection(self.slack_conn_id)
         if not conn.password:
             raise AirflowNotFoundException(
                 f"Connection ID {self.slack_conn_id!r} does not contain password (Slack API Token)."
@@ -190,6 +203,24 @@ class SlackHook(BaseHook):
         """
         return self.client.api_call(api_method, **kwargs)
 
+    async def async_call(self, api_method: str, **kwargs) -> AsyncSlackResponse:
+        """
+        Call Slack WebClient `AsyncWebClient.api_call` with given arguments.
+
+        :param api_method: The target Slack API method. e.g. 'chat.postMessage'. Required.
+        :param http_verb: HTTP Verb. Optional (defaults to 'POST')
+        :param files: Files to multipart upload. e.g. {imageORfile: file_objectORfile_path}
+        :param data: The body to attach to the request. If a dictionary is provided,
+            form-encoding will take place. Optional.
+        :param params: The URL parameters to append to the URL. Optional.
+        :param json: JSON for the body to attach to the request. Optional.
+        :return: The server's response to an HTTP request. Data from the response can be
+            accessed like a dict.  If the response included 'next_cursor' it can be
+            iterated on to execute subsequent requests.
+        """
+        client = await self.get_async_client()
+        return await client.api_call(api_method, **kwargs)
+
     def send_file_v2(
         self,
         *,
@@ -241,7 +272,6 @@ class SlackHook(BaseHook):
         initial_comment: str | None = None,
         title: str | None = None,
         snippet_type: str | None = None,
-        **kwargs,
     ) -> list[SlackResponse]:
         """
         Smooth transition between ``send_file`` and ``send_file_v2`` methods.
@@ -405,7 +435,7 @@ class SlackHook(BaseHook):
                 "password": "Slack API Token",
             },
             "placeholders": {
-                "password": "xoxb-1234567890123-09876543210987-AbCdEfGhIjKlMnOpQrStUvWx",
+                "password": "REPLACE ME WITH A SLACK ACCESS TOKEN",
                 "timeout": "30",
                 "base_url": "https://www.slack.com/api/",
                 "proxy": "http://localhost:9000",
